@@ -12,12 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+"""
+This module defines the model of a feature flag defined in App Configuration service.
+"""
+
 from typing import Any
-from .configurationType import ConfigurationType
-from ibm_appconfiguration.core.internal import Logger
+from ..internal.utils.logger import Logger
+from .configuration_type import ConfigurationType
 
 
 class Feature:
+    """Feature object"""
 
     def __init__(self, feature_list=dict):
         """
@@ -33,27 +38,42 @@ class Feature:
         self.__enabled_value = feature_list.get('enabled_value', object)
 
     def get_feature_name(self) -> str:
+        """Get the Feature name"""
         return self.__name
 
     def get_disabled_value(self) -> str:
+        """Get the Feature disabled value"""
         return self.__disabled_value
 
     def get_enabled_value(self) -> str:
+        """Get the Feature enabled value"""
         return self.__enabled_value
 
     def get_feature_id(self) -> str:
+        """Get the Feature Id"""
         return self.__feature_id
 
     def get_feature_data_type(self) -> ConfigurationType:
+        """Get the Feature data type"""
         return self.__type
 
     def is_enabled(self) -> bool:
+        """Check the Feature is enabled or not"""
         return self.__enabled
 
     def get_segment_rules(self) -> list:
+        """Get the Feature segment_rules"""
         return self.__segment_rules
 
-    def get_current_value(self, entity_id: str, entity_attributes: dict = dict()) -> Any:
+    def get_current_value(self, entity_id: str, entity_attributes: {}) -> Any:
+        """Get the Feature evaluated value
+
+        Args:
+            entity_id: Id of the Entity
+            entity_attributes: Entity attributes object
+        Returns:
+            Return the evaluated Feature value
+        """
         if not entity_id or entity_id == "":
             Logger.error("A valid entity id should be passed for this method.")
             return None
